#[repr(u32)]pub enum ActuatorConfiguration {
ACTUATOR_CONFIGURATION_NONE = 0,
ACTUATOR_CONFIGURATION_BEEP = 1,
ACTUATOR_CONFIGURATION_3D_MODE_ON = 2,
ACTUATOR_CONFIGURATION_3D_MODE_OFF = 3,
ACTUATOR_CONFIGURATION_SPIN_DIRECTION1 = 4,
ACTUATOR_CONFIGURATION_SPIN_DIRECTION2 = 5,
}Available on crate feature
dialect-matrixpilot only.Expand description
Actuator configuration, used to change a setting on an actuator. Component information metadata can be used to know which outputs support which commands.
Variants
ACTUATOR_CONFIGURATION_NONE = 0
Do nothing.
ACTUATOR_CONFIGURATION_BEEP = 1
Command the actuator to beep now.
ACTUATOR_CONFIGURATION_3D_MODE_ON = 2
Permanently set the actuator (ESC) to 3D mode (reversible thrust).
ACTUATOR_CONFIGURATION_3D_MODE_OFF = 3
Permanently set the actuator (ESC) to non 3D mode (non-reversible thrust).
ACTUATOR_CONFIGURATION_SPIN_DIRECTION1 = 4
Permanently set the actuator (ESC) to spin direction 1 (which can be clockwise or counter-clockwise).
ACTUATOR_CONFIGURATION_SPIN_DIRECTION2 = 5
Permanently set the actuator (ESC) to spin direction 2 (opposite of direction 1).
Implementations