pub struct COMMAND_CANCEL_DATA {
pub command: MavCmd,
pub target_system: u8,
pub target_component: u8,
}Available on crate feature
dialect-matrixpilot only.Expand description
Cancel a long running command. The target system should respond with a COMMAND_ACK to the original command with result=MAV_RESULT_CANCELLED if the long running process was cancelled. If it has already completed, the cancel action can be ignored. The cancel action can be retried until some sort of acknowledgement to the original command has been received. The command microservice is documented at https://mavlink.io/en/services/command.html.
ID: 80
Fields
command: MavCmdCommand ID (of command to cancel).
target_system: u8System executing long running command. Should not be broadcast (0).
target_component: u8Component executing long running command.
Implementations