pub struct HIL_STATE_QUATERNION_DATA {Show 16 fields
pub time_usec: u64,
pub attitude_quaternion: [f32; 4],
pub rollspeed: f32,
pub pitchspeed: f32,
pub yawspeed: f32,
pub lat: i32,
pub lon: i32,
pub alt: i32,
pub vx: i16,
pub vy: i16,
pub vz: i16,
pub ind_airspeed: u16,
pub true_airspeed: u16,
pub xacc: i16,
pub yacc: i16,
pub zacc: i16,
}dialect-matrixpilot only.Expand description
Sent from simulation to autopilot, avoids in contrast to HIL_STATE singularities. This packet is useful for high throughput applications such as hardware in the loop simulations.
ID: 115
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
attitude_quaternion: [f32; 4]Vehicle attitude expressed as normalized quaternion in w, x, y, z order (with 1 0 0 0 being the null-rotation)
rollspeed: f32Body frame roll / phi angular speed
pitchspeed: f32Body frame pitch / theta angular speed
yawspeed: f32Body frame yaw / psi angular speed
lat: i32Latitude
lon: i32Longitude
alt: i32Altitude
vx: i16Ground X Speed (Latitude)
vy: i16Ground Y Speed (Longitude)
vz: i16Ground Z Speed (Altitude)
ind_airspeed: u16Indicated airspeed
true_airspeed: u16True airspeed
xacc: i16X acceleration
yacc: i16Y acceleration
zacc: i16Z acceleration
Implementations