MANUAL_CONTROL_DATA

Struct MANUAL_CONTROL_DATA 

pub struct MANUAL_CONTROL_DATA {
Show 16 fields pub x: i16, pub y: i16, pub z: i16, pub r: i16, pub buttons: u16, pub target: u8, pub buttons2: u16, pub enabled_extensions: u8, pub s: i16, pub t: i16, pub aux1: i16, pub aux2: i16, pub aux3: i16, pub aux4: i16, pub aux5: i16, pub aux6: i16,
}
Available on crate feature dialect-matrixpilot only.
Manual (joystick) control message. This message represents movement axes and button using standard joystick axes nomenclature. Unused axes can be disabled and buttons states are transmitted as individual on/off bits of a bitmask. For more information see https://mavlink.io/en/manual_control.html.

ID: 69

Fields

x: i16

X-axis, normalized to the range [-1000,1000]. A value of INT16_MAX indicates that this axis is invalid. Generally corresponds to forward(1000)-backward(-1000) movement on a joystick and the pitch of a vehicle.

y: i16

Y-axis, normalized to the range [-1000,1000]. A value of INT16_MAX indicates that this axis is invalid. Generally corresponds to left(-1000)-right(1000) movement on a joystick and the roll of a vehicle.

z: i16

Z-axis, normalized to the range [-1000,1000]. A value of INT16_MAX indicates that this axis is invalid. Generally corresponds to a separate slider movement with maximum being 1000 and minimum being -1000 on a joystick and the thrust of a vehicle. Positive values are positive thrust, negative values are negative thrust.

r: i16

R-axis, normalized to the range [-1000,1000]. A value of INT16_MAX indicates that this axis is invalid. Generally corresponds to a twisting of the joystick, with clockwise being 1000 and counter-clockwise being -1000, and the yaw of a vehicle.

buttons: u16

A bitfield corresponding to the joystick buttons’ 0-15 current state, 1 for pressed, 0 for released. The lowest bit corresponds to Button 1.

target: u8

The system to be controlled.

buttons2: u16

A bitfield corresponding to the joystick buttons’ 16-31 current state, 1 for pressed, 0 for released. The lowest bit corresponds to Button 16.

enabled_extensions: u8

Set bits to 1 to indicate which of the following extension fields contain valid data: bit 0: pitch, bit 1: roll, bit 2: aux1, bit 3: aux2, bit 4: aux3, bit 5: aux4, bit 6: aux5, bit 7: aux6

s: i16

Pitch-only-axis, normalized to the range [-1000,1000]. Generally corresponds to pitch on vehicles with additional degrees of freedom. Valid if bit 0 of enabled_extensions field is set. Set to 0 if invalid.

t: i16

Roll-only-axis, normalized to the range [-1000,1000]. Generally corresponds to roll on vehicles with additional degrees of freedom. Valid if bit 1 of enabled_extensions field is set. Set to 0 if invalid.

aux1: i16

Aux continuous input field 1. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 2 of enabled_extensions field is set. 0 if bit 2 is unset.

aux2: i16

Aux continuous input field 2. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 3 of enabled_extensions field is set. 0 if bit 3 is unset.

aux3: i16

Aux continuous input field 3. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 4 of enabled_extensions field is set. 0 if bit 4 is unset.

aux4: i16

Aux continuous input field 4. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 5 of enabled_extensions field is set. 0 if bit 5 is unset.

aux5: i16

Aux continuous input field 5. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 6 of enabled_extensions field is set. 0 if bit 6 is unset.

aux6: i16

Aux continuous input field 6. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 7 of enabled_extensions field is set. 0 if bit 7 is unset.

Implementations

Source

impl MANUAL_CONTROL_DATA

pub const ENCODED_LEN: usize = 30usize

pub const DEFAULT: Self

pub fn random<R: RngCore>(rng: &mut R) -> Self

Available on crate feature arbitrary only.