pub struct ODOMETRY_DATA {Show 18 fields
pub time_usec: u64,
pub x: f32,
pub y: f32,
pub z: f32,
pub q: [f32; 4],
pub vx: f32,
pub vy: f32,
pub vz: f32,
pub rollspeed: f32,
pub pitchspeed: f32,
pub yawspeed: f32,
pub pose_covariance: [f32; 21],
pub velocity_covariance: [f32; 21],
pub frame_id: MavFrame,
pub child_frame_id: MavFrame,
pub reset_counter: u8,
pub estimator_type: MavEstimatorType,
pub quality: i8,
}dialect-matrixpilot only.Expand description
Odometry message to communicate odometry information with an external interface. Fits ROS REP 147 standard for aerial vehicles (http://www.ros.org/reps/rep-0147.html).
ID: 331
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
x: f32X Position
y: f32Y Position
z: f32Z Position
q: [f32; 4]Quaternion components, w, x, y, z (1 0 0 0 is the null-rotation)
vx: f32X linear speed
vy: f32Y linear speed
vz: f32Z linear speed
rollspeed: f32Roll angular speed
pitchspeed: f32Pitch angular speed
yawspeed: f32Yaw angular speed
pose_covariance: [f32; 21]Row-major representation of a 6x6 pose cross-covariance matrix upper right triangle (states: x, y, z, roll, pitch, yaw; first six entries are the first ROW, next five entries are the second ROW, etc.). If unknown, assign NaN value to first element in the array.
velocity_covariance: [f32; 21]Row-major representation of a 6x6 velocity cross-covariance matrix upper right triangle (states: vx, vy, vz, rollspeed, pitchspeed, yawspeed; first six entries are the first ROW, next five entries are the second ROW, etc.). If unknown, assign NaN value to first element in the array.
frame_id: MavFrameCoordinate frame of reference for the pose data.
child_frame_id: MavFrameCoordinate frame of reference for the velocity in free space (twist) data.
reset_counter: u8Estimate reset counter. This should be incremented when the estimate resets in any of the dimensions (position, velocity, attitude, angular speed). This is designed to be used when e.g an external SLAM system detects a loop-closure and the estimate jumps.
estimator_type: MavEstimatorTypeType of estimator that is providing the odometry.
quality: i8Optional odometry quality metric as a percentage. -1 = odometry has failed, 0 = unknown/unset quality, 1 = worst quality, 100 = best quality
Implementations