pub struct OPEN_DRONE_ID_AUTHENTICATION_DATA {
pub timestamp: u32,
pub target_system: u8,
pub target_component: u8,
pub id_or_mac: [u8; 20],
pub authentication_type: MavOdidAuthType,
pub data_page: u8,
pub last_page_index: u8,
pub length: u8,
pub authentication_data: [u8; 23],
}dialect-matrixpilot only.Expand description
Data for filling the OpenDroneID Authentication message. The Authentication Message defines a field that can provide a means of authenticity for the identity of the UAS (Unmanned Aircraft System). The Authentication message can have two different formats. For data page 0, the fields PageCount, Length and TimeStamp are present and AuthData is only 17 bytes. For data page 1 through 15, PageCount, Length and TimeStamp are not present and the size of AuthData is 23 bytes.
ID: 12902
Fields
timestamp: u32This field is only present for page 0. 32 bit Unix Timestamp in seconds since 00:00:00 01/01/2019.
target_system: u8System ID (0 for broadcast).
target_component: u8Component ID (0 for broadcast).
id_or_mac: [u8; 20]Only used for drone ID data received from other UAs. See detailed description at https://mavlink.io/en/services/opendroneid.html.
authentication_type: MavOdidAuthTypeIndicates the type of authentication.
data_page: u8Allowed range is 0 - 15.
last_page_index: u8This field is only present for page 0. Allowed range is 0 - 15. See the description of struct ODID_Auth_data at https://github.com/opendroneid/opendroneid-core-c/blob/master/libopendroneid/opendroneid.h.
length: u8This field is only present for page 0. Total bytes of authentication_data from all data pages. See the description of struct ODID_Auth_data at https://github.com/opendroneid/opendroneid-core-c/blob/master/libopendroneid/opendroneid.h.
authentication_data: [u8; 23]Opaque authentication data. For page 0, the size is only 17 bytes. For other pages, the size is 23 bytes. Shall be filled with nulls in the unused portion of the field.
Implementations