pub struct SMART_BATTERY_INFO_DATA {Show 17 fields
pub capacity_full_specification: i32,
pub capacity_full: i32,
pub cycle_count: u16,
pub weight: u16,
pub discharge_minimum_voltage: u16,
pub charging_minimum_voltage: u16,
pub resting_minimum_voltage: u16,
pub id: u8,
pub battery_function: MavBatteryFunction,
pub mavtype: MavBatteryType,
pub serial_number: CharArray<16>,
pub device_name: CharArray<50>,
pub charging_maximum_voltage: u16,
pub cells_in_series: u8,
pub discharge_maximum_current: u32,
pub discharge_maximum_burst_current: u32,
pub manufacture_date: CharArray<11>,
}The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
dialect-matrixpilot only.Expand description
Smart Battery information (static/infrequent update). Use for updates from: smart battery to flight stack, flight stack to GCS. Use BATTERY_STATUS for the frequent battery updates.
ID: 370
Fields
capacity_full_specification: i32The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Capacity when full according to manufacturer, -1: field not provided.
capacity_full: i32The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Capacity when full (accounting for battery degradation), -1: field not provided.
cycle_count: u16The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Charge/discharge cycle count. UINT16_MAX: field not provided.
weight: u16The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Battery weight. 0: field not provided.
discharge_minimum_voltage: u16The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Minimum per-cell voltage when discharging. If not supplied set to UINT16_MAX value.
charging_minimum_voltage: u16The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Minimum per-cell voltage when charging. If not supplied set to UINT16_MAX value.
resting_minimum_voltage: u16The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Minimum per-cell voltage when resting. If not supplied set to UINT16_MAX value.
id: u8The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Battery ID
battery_function: MavBatteryFunctionThe BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Function of the battery
mavtype: MavBatteryTypeThe BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Type (chemistry) of the battery
serial_number: CharArray<16>The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Serial number in ASCII characters, 0 terminated. All 0: field not provided.
device_name: CharArray<50>The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Static device name in ASCII characters, 0 terminated. All 0: field not provided. Encode as manufacturer name then product name separated using an underscore.
charging_maximum_voltage: u16The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Maximum per-cell voltage when charged. 0: field not provided.
cells_in_series: u8The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Number of battery cells in series. 0: field not provided.
discharge_maximum_current: u32The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Maximum pack discharge current. 0: field not provided.
discharge_maximum_burst_current: u32The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Maximum pack discharge burst current. 0: field not provided.
manufacture_date: CharArray<11>The BATTERY_INFO message is better aligned with UAVCAN messages, and in any case is useful even if a battery is not “smart”. See BATTERY_INFO (Superseded since 2024-02)
Manufacture date (DD/MM/YYYY) in ASCII characters, 0 terminated. All 0: field not provided.
Implementations